@@ -176,8 +176,10 @@ class BaseUsbDriver(BaseDriver):
     def port(self):
         """Physical location of the device, or None if N/A.
 
-        Tuple of USB port numbers, from the root hub to this device.  Not
-        dependendent on bus enumeration order.
+        Tuple of USB port numbers, from the root hub to this device.
+
+        Only available for PyUSB-backed devices, and only when using LibUSB 1.0.
+        But has the advantage of not depending on the bus enumeration order.
         """
         return self.device.port
 
@@ -615,7 +617,7 @@ class PyUsbBus(BaseBus):
         for handle in PyUsbDevice.enumerate(vendor, product):
             if bus and handle.bus != bus:
                 continue
-            if address and handle.address != address:
+            if address and str(handle.address) != address:
                 continue
             if usb_port and handle.port != usb_port:
                 continue
